@@ -1,6 +1,5 @@
 import io
-import time
-
+import socket
 from britive.britive import Britive
 from .helpers.config import ConfigManager
 from .helpers.credentials import FileCredentialManager, EncryptedFileCredentialManager
@@ -14,9 +13,11 @@ from .helpers.cache import Cache
 from britive import exceptions
 from pathlib import Path
 from datetime import datetime
+import os
 
 
 default_table_format = 'fancy_grid'
+debug_enabled = os.getenv('PYBRITIVE_DEBUG')
 
 
 class BritiveCli:
@@ -97,9 +98,13 @@ class BritiveCli:
         if self.token:
             raise click.ClickException('Logout not available when using an API token.')
         self.login()
-        self.b.delete(f'https://{self.tenant_name}.britive-app.com/api/auth')
+        self.b.delete(f'https://{Britive.parse_tenant(self.tenant_name)}/api/auth')
         self._cleanup_credentials()
 
+    def debug(self, data: object, ignore_silent: bool = False):
+        if debug_enabled:
+            self.print(data=data, ignore_silent=ignore_silent)
+
     # will take a list of dicts and print to the screen based on the format specified in the config file
     # dict can only be 1 level deep (no nesting) - caller needs to massage the data accordingly
     def print(self, data: object, ignore_silent: bool = False):
@@ -153,10 +158,13 @@ class BritiveCli:
         self.login()
         self._set_available_profiles()
         data = []
-        checked_out_profiles = [p['papId'] for p in self.b.my_access.list_checked_out_profiles()] if checked_out else []
+        checked_out_profiles = [
+            f'{p["papId"]}-{p["environmentId"]}'
+            for p in self.b.my_access.list_checked_out_profiles()
+        ] if checked_out else []
 
         for profile in self.available_profiles:
-            if not checked_out or profile['profile_id'] in checked_out_profiles:
+            if not checked_out or f'{profile["profile_id"]}-{profile["env_id"]}' in checked_out_profiles:
                 row = {
                     'Application': profile['app_name'],
                     'Environment': profile['env_name'],
@@ -295,6 +303,7 @@ class BritiveCli:
     def _checkout(self, profile_name, env_name, app_name, programmatic, blocktime, maxpolltime, justification):
         try:
             self.login()
+
             return self.b.my_access.checkout_by_name(
                 profile_name=profile_name,
                 environment_name=env_name,
@@ -309,6 +318,14 @@ class BritiveCli:
             raise click.ClickException('approval required and no justification provided.')
         except ValueError as e:
             raise click.BadParameter(str(e))
+        except Exception as e:
+            if 'programmatic access is not enabled' in str(e).lower():
+                # attempt to automatically checkout console access instead
+                # this is a cli only feature - not available in the sdk
+                self.print('no programmatic access available - checking out console access instead')
+                return self._checkout(profile_name, env_name, app_name, False, blocktime, maxpolltime, justification)
+            else:
+                raise e
 
     @staticmethod
     def _should_check_force_renew(app, force_renew, console):
